@@ -28,6 +28,7 @@
 #include <cstring>
 #include <cstdlib>
 #include <vector>
+#include <zlib.h>
 
 #include "encoder_png.h"
 #include "libheif/exif.h"
@@ -51,6 +52,10 @@ bool PngEncoder::Encode(const struct heif_image_handle* handle,
     return false;
   }
 
+  if (m_compression_level != -1) {
+    png_set_compression_level(png_ptr, m_compression_level);
+  }
+
   FILE* fp = fopen(filename.c_str(), "wb");
   if (!fp) {
     fprintf(stderr, "Can't open %s: %s\n", filename.c_str(), strerror(errno));
@@ -87,7 +92,6 @@ bool PngEncoder::Encode(const struct heif_image_handle* handle,
   png_set_IHDR(png_ptr, info_ptr, width, height, bitDepth, colorType,
                PNG_INTERLACE_NONE, PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
 
-
   // --- write ICC profile
 
   size_t profile_size = heif_image_handle_get_raw_color_profile_size(handle);
