@@ -96,9 +96,11 @@ void show_help(const char* argv0)
 }
 
 
-class LibHeifInitializer {
+class LibHeifInitializer
+{
 public:
   LibHeifInitializer() { heif_init(nullptr); }
+
   ~LibHeifInitializer() { heif_deinit(); }
 };
 
@@ -170,33 +172,31 @@ int main(int argc, char** argv)
       fclose(fh);
 
       char fourcc[5];
-      fourcc[4]=0;
-      heif_brand_to_fourcc( heif_read_main_brand(buf,bufSize), fourcc );
+      fourcc[4] = 0;
+      heif_brand_to_fourcc(heif_read_main_brand(buf, bufSize), fourcc);
       std::cout << "main brand: " << fourcc << "\n";
 
-      heif_brand2* brands=nullptr;
-      int nBrands=0;
-      struct heif_error err=heif_list_compatible_brands(buf, n, &brands, &nBrands);
+      heif_brand2* brands = nullptr;
+      int nBrands = 0;
+      struct heif_error err = heif_list_compatible_brands(buf, n, &brands, &nBrands);
       if (err.code) {
-	std::cerr << "error reading brands: " << err.message << "\n";
+        std::cerr << "error reading brands: " << err.message << "\n";
       }
       else {
-	std::cout << "compatible brands: ";
-	for (int i=0;i<nBrands;i++) {
-	  heif_brand_to_fourcc(brands[i], fourcc);
-	  if (i>0) {
-	    std::cout << ", ";
-	  }
-	  std::cout << fourcc;
-	}
-	
-	std::cout << "\n";
+        std::cout << "compatible brands: ";
+        for (int i = 0; i < nBrands; i++) {
+          heif_brand_to_fourcc(brands[i], fourcc);
+          if (i > 0) {
+            std::cout << ", ";
+          }
+          std::cout << fourcc;
+        }
 
-	heif_free_list_of_compatible_brands(brands);
+        std::cout << "\n";
+
+        heif_free_list_of_compatible_brands(brands);
       }
     }
-
-    std::cout << "\n";
   }
 
   // ==============================================================================
@@ -230,6 +230,8 @@ int main(int argc, char** argv)
   heif_context_get_list_of_top_level_image_IDs(ctx.get(), IDs.data(), numImages);
 
   for (int i = 0; i < numImages; i++) {
+    std::cout << "\n";
+
     struct heif_image_handle* handle;
     struct heif_error err = heif_context_get_image_handle(ctx.get(), IDs[i], &handle);
     if (err.code) {
@@ -351,31 +353,210 @@ int main(int argc, char** argv)
 
     int numMetadata = heif_image_handle_get_number_of_metadata_blocks(handle, nullptr);
     printf("metadata:\n");
-    if (numMetadata>0) {
+    if (numMetadata > 0) {
       std::vector<heif_item_id> ids(numMetadata);
       heif_image_handle_get_list_of_metadata_block_IDs(handle, nullptr, ids.data(), numMetadata);
 
-      for (int n=0;n<numMetadata;n++) {
+      for (int n = 0; n < numMetadata; n++) {
         std::string itemtype = heif_image_handle_get_metadata_type(handle, ids[n]);
         std::string contenttype = heif_image_handle_get_metadata_content_type(handle, ids[n]);
         std::string ID{"unknown"};
-        if (itemtype=="Exif") {
+        if (itemtype == "Exif") {
           ID = itemtype;
         }
-        else if (contenttype=="application/rdf+xml") {
+        else if (contenttype == "application/rdf+xml") {
           ID = "XMP";
         }
         else {
           ID = itemtype + "/" + contenttype;
         }
 
-        printf("  %s: %zu bytes\n",ID.c_str(), heif_image_handle_get_metadata_size(handle,ids[n]));
+        printf("  %s: %zu bytes\n", ID.c_str(), heif_image_handle_get_metadata_size(handle, ids[n]));
       }
     }
     else {
       printf("  none\n");
     }
 
+    // --- transforms
+
+#define MAX_PROPERTIES 50
+    heif_property_id transforms[MAX_PROPERTIES];
+    int nTransforms = heif_item_get_transformation_properties(ctx.get(),
+                                                              IDs[i],
+                                                              transforms,
+                                                              MAX_PROPERTIES);
+    printf("transformations:\n");
+    int image_width = heif_image_handle_get_ispe_width(handle);
+    int image_height = heif_image_handle_get_ispe_height(handle);
+
+    if (nTransforms) {
+      for (int k = 0; k < nTransforms; k++) {
+        switch (heif_item_get_property_type(ctx.get(), IDs[i], transforms[k])) {
+          case heif_item_property_type_transform_mirror:
+            printf("  mirror: %s\n", heif_item_get_property_transform_mirror(ctx.get(), IDs[i], transforms[k]) == heif_transform_mirror_direction_horizontal ? "horizontal" : "vertical");
+            break;
+          case heif_item_property_type_transform_rotation: {
+            int angle = heif_item_get_property_transform_rotation_ccw(ctx.get(), IDs[i], transforms[k]);
+            printf("  angle (ccw): %d\n", angle);
+            if (angle==90 || angle==270) {
+              std::swap(image_width, image_height);
+            }
+            break;
+          }
+          case heif_item_property_type_transform_crop: {
+            int left,top,right,bottom;
+            heif_item_get_property_transform_crop_borders(ctx.get(), IDs[i], transforms[k], image_width, image_height,
+                                                          &left, &top, &right, &bottom);
+            printf("  crop: left=%d top=%d right=%d bottom=%d\n", left,top,right,bottom);
+            break;
+          }
+          default:
+            assert(false);
+        }
+      }
+    }
+    else {
+      printf("  none\n");
+    }
+
+    // --- regions
+
+    int numRegionItems = heif_image_handle_get_number_of_region_items(handle);
+    printf("region annotations:\n");
+    if (numRegionItems > 0) {
+      std::vector<heif_item_id> region_items(numRegionItems);
+      heif_image_handle_get_list_of_region_item_ids(handle, region_items.data(), numRegionItems);
+      for (heif_item_id region_item_id : region_items) {
+        struct heif_region_item* region_item;
+        err = heif_context_get_region_item(ctx.get(), region_item_id, &region_item);
+
+        uint32_t reference_width, reference_height;
+        heif_region_item_get_reference_size(region_item, &reference_width, &reference_height);
+        int numRegions = heif_region_item_get_number_of_regions(region_item);
+        printf("  id: %u, reference_width: %u, reference_height: %u, %d regions\n",
+               region_item_id,
+               reference_width,
+               reference_height,
+               numRegions);
+
+        std::vector<heif_region*> regions(numRegions);
+        numRegions = heif_region_item_get_list_of_regions(region_item, regions.data(), numRegions);
+        for (int j = 0; j < numRegions; j++) {
+          printf("    region %d\n", j);
+          heif_region_type type = heif_region_get_type(regions[j]);
+          if (type == heif_region_type_point) {
+            int32_t x;
+            int32_t y;
+            heif_region_get_point(regions[j], &x, &y);
+            printf("      point [x=%i, y=%i]\n", x, y);
+          }
+          else if (type == heif_region_type_rectangle) {
+            int32_t x;
+            int32_t y;
+            uint32_t w;
+            uint32_t h;
+            heif_region_get_rectangle(regions[j], &x, &y, &w, &h);
+            printf("      rectangle [x=%i, y=%i, w=%u, h=%u]\n", x, y, w, h);
+#if 0
+            double dx;
+            double dy;
+            double dw;
+            double dh;
+            heif_region_get_rectangle_scaled(regions[j], &dx, &dy, &dw, &dh, IDs[i]);
+            printf("      rectangle [x=%lf, y=%lf, w=%lf, h=%lf]\n", dx, dy, dw, dh);
+#endif
+          }
+          else if (type == heif_region_type_ellipse) {
+            int32_t x;
+            int32_t y;
+            uint32_t rx;
+            uint32_t ry;
+            heif_region_get_ellipse(regions[j], &x, &y, &rx, &ry);
+            printf("      ellipse [x=%i, y=%i, r_x=%u, r_y=%u]\n", x, y, rx, ry);
+          }
+          else if (type == heif_region_type_polygon) {
+            int32_t numPoints = heif_region_get_polygon_num_points(regions[j]);
+            std::vector<int32_t> pts(numPoints*2);
+            heif_region_get_polygon_points(regions[j], pts.data());
+            printf("      polygon [");
+            for (int p=0;p<numPoints;p++) {
+              printf("(%d;%d)", pts[2*p+0], pts[2*p+1]);
+            }
+            printf("]\n");
+          }
+          else if (type == heif_region_type_polyline) {
+            int32_t numPoints = heif_region_get_polyline_num_points(regions[j]);
+            std::vector<int32_t> pts(numPoints*2);
+            heif_region_get_polyline_points(regions[j], pts.data());
+            printf("      polyline [");
+            for (int p=0;p<numPoints;p++) {
+              printf("(%d;%d)", pts[2*p+0], pts[2*p+1]);
+            }
+            printf("]\n");
+          }
+      }
+
+        heif_region_release_many(regions.data(), numRegions);
+        heif_region_item_release(region_item);
+
+        heif_property_id properties[MAX_PROPERTIES];
+        int nDescr = heif_item_get_properties_of_type(ctx.get(),
+                                                      region_item_id,
+                                                      heif_item_property_type_user_description,
+                                                      properties,
+                                                      MAX_PROPERTIES);
+
+        for (int k = 0; k < nDescr; k++) {
+          heif_property_user_description* udes;
+          err = heif_item_get_property_user_description(ctx.get(),
+                                                        region_item_id,
+                                                        properties[k],
+                                                        &udes);
+          if (err.code == 0) {
+            printf("    user description:\n");
+            printf("      lang: %s\n", udes->lang);
+            printf("      name: %s\n", udes->name);
+            printf("      description: %s\n", udes->description);
+            printf("      tags: %s\n", udes->tags);
+            heif_property_user_description_release(udes);
+          }
+        }
+      }
+    }
+    else {
+      printf("  none\n");
+    }
+
+    // --- properties
+
+    printf("properties:\n");
+
+    // user descriptions
+
+    heif_property_id propertyIds[MAX_PROPERTIES];
+    int count;
+    count = heif_item_get_properties_of_type(ctx.get(), IDs[i], heif_item_property_type_user_description,
+                                             propertyIds, MAX_PROPERTIES);
+
+    if (count > 0) {
+      for (int p = 0; p < count; p++) {
+        struct heif_property_user_description* udes;
+        err = heif_item_get_property_user_description(ctx.get(), IDs[i], propertyIds[p], &udes);
+        if (err.code) {
+          std::cerr << "Error reading udes " << IDs[i] << "/" << propertyIds[p] << "\n";
+        }
+        else {
+          printf("  user description:\n");
+          printf("    lang: %s\n", udes->lang);
+          printf("    name: %s\n", udes->name);
+          printf("    description: %s\n", udes->description);
+          printf("    tags: %s\n", udes->tags);
+
+          heif_property_user_description_release(udes);
+        }
+      }
+    }
 
     struct heif_image* image;
     err = heif_decode_image(handle,
