@@ -415,7 +415,7 @@ public:
                              const char* item_type, const char* content_type,
                              heif_metadata_compression compression);
 
-  heif_property_id add_property(heif_item_id targetItem, std::shared_ptr<Box> property);
+  heif_property_id add_property(heif_item_id targetItem, std::shared_ptr<Box> property, bool essential);
 
   // --- region items
 
